@@ -14,7 +14,6 @@ import tempfile
 from datetime import datetime
 from pathlib import Path
 from urllib.parse import urlparse, unquote
-
 from bs4 import BeautifulSoup
 from colorama import Fore, Style, init as colorama_init
 
@@ -22,28 +21,23 @@ from colorama import Fore, Style, init as colorama_init
 colorama_init(autoreset=True)
 
 AUTOPOSTS_FILE = "autoposts.json"
-DEFAULT_INTERVAL = 300  # seconds
+DEFAULT_INTERVAL = 300    # seconds
 
-logging.basicConfig(
-    level=logging.INFO,
-    format="%(asctime)s [%(levelname)s] %(message)s"
-)
+logging.basicConfig(level=logging.INFO,
+                    format="%(asctime)s [%(levelname)s] %(message)s")
 
 # —————— Persistence ——————————————————————————————
 DEFAULT_DATA = {"usernames": {}, "interval": DEFAULT_INTERVAL}
 
-
 def save_data(data):
     with open(AUTOPOSTS_FILE, "w") as f:
         json.dump(data, f, indent=4)
 
-
 def load_data():
     if not os.path.exists(AUTOPOSTS_FILE):
         print(Fore.YELLOW + "No state file found; creating new one.")
         save_data(DEFAULT_DATA)
         return DEFAULT_DATA.copy()
-
     try:
         with open(AUTOPOSTS_FILE, "r") as f:
             data = json.load(f)
@@ -59,14 +53,11 @@ def load_data():
     if not isinstance(data.get("interval"), int):
         data["interval"] = DEFAULT_INTERVAL
         changed = True
-
     if changed:
         print(Fore.YELLOW + "Fixing state file structure.")
         save_data(data)
-
     return data
 
-
 # —————— Utility for slugifying titles ——————————————————
 def slugify(text: str) -> str:
     text = text.lower().strip()
@@ -74,7 +65,6 @@ def slugify(text: str) -> str:
     text = re.sub(r"[\s_-]+", "-", text)
     return text
 
-
 # —————— Extracting media URLs for highlights/spotlights ——————————————————
 def extract_media_urls(data):
     """
@@ -112,7 +102,6 @@ def extract_media_urls(data):
         logging.debug(f"[extract_media_urls] album='{album}' → {len(urls)} URLs")
     return media
 
-
 # —————— Snapchat Fetching Helpers —————————————————————
 async def get_json(session, username):
     url = f"https://story.snapchat.com/@{username}"
@@ -132,7 +121,6 @@ async def get_json(session, username):
             print(Fore.RED + f"{username}: JSON parse error: {e}")
             return None
 
-
 # —————— Download a single media URL to a specific directory ——————————————————
 async def download_media_to_dir(session, url, dest_dir):
     os.makedirs(dest_dir, exist_ok=True)
@@ -158,7 +146,6 @@ async def download_media_to_dir(session, url, dest_dir):
                 await f.write(chunk)
         return path
 
-
 # —————— ZIP creation ———————————————————————————
 async def create_zip(username, files):
     zdir = os.path.join("zips", username)
@@ -170,7 +157,6 @@ async def create_zip(username, files):
             zf.write(f, os.path.basename(f))
     return zpath
 
-
 # —————— Core Processing (stories + highlights + spotlights) —————————————————
 async def process_username(username, session, data, force_zip=False):
     cfg = data["usernames"].setdefault(username, {"last": []})
@@ -183,14 +169,9 @@ async def process_username(username, session, data, force_zip=False):
     page_props = raw.get("props", {}).get("pageProps", {})
     story = page_props.get("story") or {}
     snaps = story.get("snapList", [])
-    story_urls = [
-        s.get("snapUrls", {}).get("mediaUrl")
-        for s in snaps
-        if s.get("snapUrls", {}).get("mediaUrl")
-    ]
+    story_urls = [s.get("snapUrls", {}).get("mediaUrl") for s in snaps if s.get("snapUrls", {}).get("mediaUrl")]
     new_story = [u for u in story_urls if u not in last]
     story_files = []
-
     if new_story:
         print(Fore.GREEN + f"{username}: found {len(new_story)} new story item(s), downloading…")
         story_tasks = [
@@ -203,10 +184,8 @@ async def process_username(username, session, data, force_zip=False):
             if force_zip:
                 z = await create_zip(username, story_files)
                 for f in story_files:
-                    try:
-                        os.remove(f)
-                    except:
-                        pass
+                    try: os.remove(f)
+                    except: pass
                 print(Fore.MAGENTA + f"{username}: downloaded {len(story_files)} story snaps (zipped → {z})")
             else:
                 print(Fore.MAGENTA + f"{username}: downloaded {len(story_files)} story snaps")
@@ -220,8 +199,7 @@ async def process_username(username, session, data, force_zip=False):
 
     # — Spotlights (parallelized with gather) —
     spotlight_urls = [
-        url
-        for key, lst in media_map.items()
+        url for key, lst in media_map.items()
         if "spotlight" in key.lower()
         for url in lst
     ]
@@ -240,10 +218,8 @@ async def process_username(username, session, data, force_zip=False):
             if force_zip:
                 z_spot = await create_zip(username, spot_files)
                 for f in spot_files:
-                    try:
-                        os.remove(f)
-                    except:
-                        pass
+                    try: os.remove(f)
+                    except: pass
                 print(Fore.MAGENTA + f"{username}: downloaded {len(spot_files)} spotlight snaps (zipped → {z_spot})")
             else:
                 print(Fore.MAGENTA + f"{username}: downloaded {len(spot_files)} spotlight snaps")
@@ -254,10 +230,7 @@ async def process_username(username, session, data, force_zip=False):
         print(Fore.CYAN + f"{username}: no new spotlight snaps.")
 
     # — Highlights (parallelized with gather) —
-    highlight_keys = sorted(
-        [k for k in media_map.keys() if "spotlight" not in k.lower()],
-        key=lambda s: s.lower()
-    )
+    highlight_keys = sorted([k for k in media_map.keys() if "spotlight" not in k.lower()], key=lambda s: s.lower())
     highlight_pairs = [
         (album_title, u)
         for album_title in highlight_keys
@@ -279,10 +252,8 @@ async def process_username(username, session, data, force_zip=False):
             if force_zip:
                 z_high = await create_zip(username, high_files)
                 for f in high_files:
-                    try:
-                        os.remove(f)
-                    except:
-                        pass
+                    try: os.remove(f)
+                    except: pass
                 print(Fore.MAGENTA + f"{username}: downloaded {len(high_files)} highlight snaps (zipped → {z_high})")
             else:
                 print(Fore.MAGENTA + f"{username}: downloaded {len(high_files)} highlight snaps")
@@ -296,7 +267,6 @@ async def process_username(username, session, data, force_zip=False):
     cfg["last"] = list(last)
     save_data(data)
 
-
 # —————— Highlights-Only Download Helper (parallelized) ———————————————————————————
 async def download_highlights_only(username, session, data, force_zip=False):
     cfg = data["usernames"].setdefault(username, {"last": []})
@@ -307,10 +277,7 @@ async def download_highlights_only(username, session, data, force_zip=False):
         return
 
     media_map = extract_media_urls(raw)
-    highlight_keys = sorted(
-        [k for k in media_map.keys() if "spotlight" not in k.lower()],
-        key=lambda s: s.lower()
-    )
+    highlight_keys = sorted([k for k in media_map.keys() if "spotlight" not in k.lower()], key=lambda s: s.lower())
     highlight_pairs = [
         (album_title, u)
         for album_title in highlight_keys
@@ -338,10 +305,8 @@ async def download_highlights_only(username, session, data, force_zip=False):
     if force_zip:
         z_high = await create_zip(username, high_files)
         for f in high_files:
-            try:
-                os.remove(f)
-            except:
-                pass
+            try: os.remove(f)
+            except: pass
         print(Fore.MAGENTA + f"{username}: downloaded {len(high_files)} highlight snaps (zipped → {z_high})")
     else:
         print(Fore.MAGENTA + f"{username}: downloaded {len(high_files)} highlight snaps")
@@ -350,7 +315,6 @@ async def download_highlights_only(username, session, data, force_zip=False):
     cfg["last"] = list(last)
     save_data(data)
 
-
 # —————— Spotlights-Only Download Helper (parallelized) —————————————————————————————
 async def download_spotlights_only(username, session, data, force_zip=False):
     cfg = data["usernames"].setdefault(username, {"last": []})
@@ -362,8 +326,7 @@ async def download_spotlights_only(username, session, data, force_zip=False):
 
     media_map = extract_media_urls(raw)
     spotlight_urls = [
-        url
-        for key, lst in media_map.items()
+        url for key, lst in media_map.items()
         if "spotlight" in key.lower()
         for url in lst
     ]
@@ -388,10 +351,8 @@ async def download_spotlights_only(username, session, data, force_zip=False):
     if force_zip:
         z_spot = await create_zip(username, spot_files)
         for f in spot_files:
-            try:
-                os.remove(f)
-            except:
-                pass
+            try: os.remove(f)
+            except: pass
         print(Fore.MAGENTA + f"{username}: downloaded {len(spot_files)} spotlight snaps (zipped → {z_spot})")
     else:
         print(Fore.MAGENTA + f"{username}: downloaded {len(spot_files)} spotlight snaps")
@@ -400,7 +361,6 @@ async def download_spotlights_only(username, session, data, force_zip=False):
     cfg["last"] = list(last)
     save_data(data)
 
-
 # —————— Monitoring Loops ———————————————————————————
 async def check_loop_all(data, force_zip=False):
     interval = data["interval"]
@@ -411,7 +371,6 @@ async def check_loop_all(data, force_zip=False):
             print(Fore.YELLOW + f"Sleeping {interval}s…")
             await asyncio.sleep(interval)
 
-
 async def check_loop_highlights(data, force_zip=False):
     interval = data["interval"]
     async with aiohttp.ClientSession() as session:
@@ -421,7 +380,6 @@ async def check_loop_highlights(data, force_zip=False):
             print(Fore.YELLOW + f"Sleeping {interval}s…")
             await asyncio.sleep(interval)
 
-
 async def check_loop_spotlights(data, force_zip=False):
     interval = data["interval"]
     async with aiohttp.ClientSession() as session:
@@ -431,7 +389,6 @@ async def check_loop_spotlights(data, force_zip=False):
             print(Fore.YELLOW + f"Sleeping {interval}s…")
             await asyncio.sleep(interval)
 
-
 # —————— CLI —————————————————————————————————————
 def main():
     parser = argparse.ArgumentParser(
@@ -455,7 +412,7 @@ def main():
         help="bundle downloaded snaps into a ZIP"
     )
     parser.add_argument(
-        "--highlights", "-H", action="store_true",
+        "-hl", action="store_true",
         help="download only highlights for added users"
     )
     parser.add_argument(
@@ -497,7 +454,7 @@ def main():
         print(Fore.YELLOW + f"Set interval = {args.check_interval}s")
         changed = True
 
-    # On config change without “start”: save & one-off
+    # on config change without “start”: save & one-off
     if changed and args.command != "start":
         save_data(data)
         if added:
@@ -512,16 +469,14 @@ def main():
                     else:
                         for u in added:
                             await process_username(u, session, data, force_zip=args.zip)
-
             asyncio.run(oneoff())
-
         print(Style.BRIGHT + "\nTo start monitoring for new snaps, run:")
         zip_flag = " -z" if args.zip else ""
         mode_flag = ""
         if args.spotlights:
             mode_flag = " -s"
         elif args.highlights:
-            mode_flag = " -H"
+            mode_flag = " -hl"
         print(Fore.CYAN + f"  snapify start{mode_flag}{zip_flag}\n")
         sys.exit(0)
 
@@ -542,6 +497,5 @@ def main():
 
     parser.print_help()
 
-
 if __name__ == "__main__":
     main()
